import { CommandBase } from './CommandBase';
/**
 * Image format.
 * @remarks
 * This type represents the allowed image formats.
 */
export type MimeType = 'image/png' | 'image/jpeg' | 'image/webp';
/**
 * Represents a command to get fast render.
 *
 * **Important**: Invoking this command will buffer it until the viewport is ready. Only then will the request be processed.
 *
 * @example
 * import { GetScreenshot,Communicator,saveImage } from '@3dsource/metabox-front-api';
 * window.env3DSource.apiReady = (api:Communicator) => {
 *   // Listen for events from the MetaBox API
 *   api.addEventListener('screenshot', (data) => {
 *     // Process the fast render response
 *    saveImage(data, 'Render.png');
 *   });
 *   api.sendCommandToMetaBox(new GetScreenshot('image/png', { x: 1024, y: 1024 }));
 * };
 */
export declare class GetScreenshot extends CommandBase {
    /**
     * Constructs an instance of GetScreenshot.
     * @param mimeType - The output format.
     * @param size - Optional size in pixels.
     */
    constructor(mimeType: MimeType, size?: {
        x: number;
        y: number;
    });
}
