import { CommandBase } from './CommandBase';
/**
 * Represents a command to set a product by its ID.
 *
 * @remarks
 * This action sends a message to the MetaBox API to set a product using the provided product ID.
 *
 * @example
 * import { SetProduct,Communicator } from '@3dsource/metabox-front-api';
 *
 * //...Assume that the integration is already implemented
 * window.env3DSource.apiReady = (api:Communicator) => {
 *   api.setCommandToMetaBox(new SetProduct(
 *     'ffea6b5c-3a8a-4f56-9417-e605acb5cca3'
 *   ));
 * };
 */
export declare class SetProduct extends CommandBase {
    /**
     * Creates an instance of SetProduct.
     *
     * @param productId - The product ID.
     */
    constructor(productId: string);
}
