import { CommandBase } from './CommandBase';
/**
 * Represents a command to toggle the Unreal Overlay Interface Menu.
 *
 * @remarks
 * This action sends a message to the MetaBox API to toggle the visibility of the Unreal overlay UI.
 *
 * @example
 * import { ShowOverlayInterface,Communicator } from '@3dsource/metabox-front-api';
 *
 * //...Assume that the integration is already implemented
 * window.env3DSource.apiReady = (api:Communicator) => {
 *   api.setCommandToMetaBox(new ShowOverlayInterface(true));
 * };
 */
export declare class ShowOverlayInterface extends CommandBase {
    /**
     * Creates an instance of ShowOverlayInterface.
     *
     * @param visible - A flag indicating whether the Unreal overlay UI should be visible.
     */
    constructor(visible: boolean);
}
