import type { ConfiguratorEnvelope } from './UniversalConfigurator';
import type { StreamResolutionProps, UnrealCallBackJson, UnrealState } from '@3dsource/angular-unreal-module';
export interface FromMetaboxMessagePayloads {
    /**
     * Dispatches Every time the configurator data is updated.
     * I.e., when the user changes the configuration. (Material, Product, Environment)
     */
    configuratorData: ConfiguratorEnvelope;
    /**
     * @hidden
     * @deprecated, use configuratorData instead.
     */
    basicConfiguratorDataWithState: ConfiguratorEnvelope;
    /**
     * Dispatches Every time when the configurator connected/disconnected with Unreal Engine.
     */
    dataChannelConnected: boolean;
    /**
     * Dispatches Every time when the Unreal Viewport is visible/hidden.
     */
    viewportReady: boolean;
    /**
     * Dispatches Every when user toggles fullscreen button in an internal menu.
     */
    isFullScreen: boolean;
    /**
     * Dispatches at the moment while the configurator loads. Shows status information.
     */
    statusMessage: string | null;
    /**
     * @deprecated
     * @hidden
     * Dispatches every time when the freeze-frame is arrived or updated.
     */
    freezeFrame: {
        dataUrl: string | null;
        progress: number | null;
    };
    /**
     * @experimental
     * Dispatches every Unreal is sending a command callback.
     * Works only after the new WatchCallbacks () command is sent.
     */
    unrealCallback: {
        json: UnrealCallBackJson;
    };
    /**
     * Dispatches every time when Unreal is sending ordered render with new GetFastRender() command.
     */
    screenshot: string | null;
    getScreenshot: string | null;
    /**
     * @hidden
     * @deprecated, use screenshot
     */
    fastRender: string | null;
    /**
     * @hidden
     * @deprecated, use fastRender
     */
    getFastRender: string | null;
    /**
     * @experimental
     * Dispatches every Unreal state is changing, including all unreal module state.
     */
    unrealState: UnrealState;
    /**
     * @hidden
     * @deprecated, use unrealState
     */
    unrealFeature: UnrealState;
    /**
     * Dispatches every time when Unreal is changing its video stream size.
     */
    videoResolution: StreamResolutionProps;
    /**
     * @hidden
     * @deprecated, use videoResolution
     */
    streamResolution: StreamResolutionProps;
}
/**
 * @hidden
 */
export type FromMetaBoxApiEvents = keyof FromMetaboxMessagePayloads;
/**
 * @internal
 * This creates all event envelopes defined in MetaBoxAPIPayloads.
 */
export interface MetaBoxApiEnvelope<T extends FromMetaBoxApiEvents> {
    action: 'bridge';
    eventType: T;
    payload: FromMetaboxMessagePayloads[T];
}
/**
 * @hidden
 * @internal
 * Used for signaling that the app is loaded and ready to open api.
 */
export interface MCAppLoaded {
    action: 'appLoaded';
    eventType?: unknown;
    payload?: unknown;
}
/**
 * @internal
 * @hidden
 * This creates a union of all event envelopes defined in MetaBoxAPIPayloads.
 */
export type FromMetaBoxAPIEnvelope = {
    [K in keyof FromMetaboxMessagePayloads]: MetaBoxApiEnvelope<K>;
}[keyof FromMetaboxMessagePayloads] | MCAppLoaded;
export interface FromMetaBoxMessage {
    host: 'metabox';
    payload: FromMetaBoxAPIEnvelope;
}
