import type { MimeType } from '../actions/GetScreenshot';
import type { ApplicationDeviceTypes } from './application-device-types';
import type { MetaBoxCommandPacket } from '@3dsource/types-unreal';
export type ToMetaBoxActions = 'getPdf' | 'loadLevel' | 'setProduct' | 'getFastRender' | 'getScreenshot' | 'watchCallbacks' | 'setMaterialById' | 'showEmbeddedMenu' | 'forceSetDeviceType' | 'sendCommandToUnreal' | 'showOverlayInterface' | 'setEnvironmentMaterialById' | 'resetCamera' | 'addResponse';
/**
 * @internal
 * @hidden
 */
export type ToMetaboxMessagePayload = ToMetaboxMessagePayloads[keyof ToMetaboxMessagePayloads];
/**
 * Interface for messages sent from the application to the MetaBox.
 */
export interface ToMetaboxMessagePayloads {
    getPdf: void;
    loadLevel: {
        id: string;
    };
    setProduct: {
        productId: string;
    };
    /**
     * @deprecated
     * @hidden
     */
    addResponse: void;
    /**
     * @deprecated
     * @hidden
     */
    getFastRender: {
        format: MimeType;
        size?: {
            x: number;
            y: number;
        };
    };
    getScreenshot: {
        format: MimeType;
        size?: {
            x: number;
            y: number;
        };
    };
    watchCallbacks: void;
    setMaterialById: {
        slotId: string;
        materialId: string;
    };
    sendCommandToUnreal: MetaBoxCommandPacket;
    setEnvironmentMaterialById: {
        slotId: string;
        materialId: string;
    };
    showEmbeddedMenu: {
        visible: boolean;
    };
    showOverlayInterface: {
        visible: boolean;
    };
    forceSetDeviceType: {
        deviceType: ApplicationDeviceTypes;
    };
    resetCamera: void;
}
export interface ToMetaBoxMessageEnvelope {
    action: ToMetaBoxActions;
    payload?: ToMetaboxMessagePayload | never;
}
export interface ToMetaBoxMessage {
    host: 'metaBoxHost';
    payload: ToMetaBoxMessageEnvelope;
}
