import { EventDispatcher } from './EventDispatcher';
import type { CommandBase } from '../actions/CommandBase';
import type { FromMetaBoxApiEvents, FromMetaboxMessagePayloads } from '../interfaces/FromMetaboxMessagePayloads';
/**
 * Handles messaging between the host page and embedded MetaBox content.
 * @internal Use {@link Communicator.createInstance} or the {@link integrateMetaBox} helper to instantiate.
 */
export declare class Communicator extends EventDispatcher {
    /**
     * Bound handler for incoming postMessage events.
     */
    private binder;
    /**
     * Singleton reference to the current communicator instance.
     */
    static instance: Communicator | null;
    /**
     * Constructs a Communicator, replacing any existing instance, and begins listening for messages.
     * @internal
     */
    constructor();
    /**
     * Cleans up resources and stops listening for messages.
     */
    destroy(): void;
    /**
     * Posts a command to the MetaBox iframe.
     * @param command - An action command containing data to send.
     */
    sendCommandToMetaBox<T extends CommandBase>(command: T): void;
    /**
     * Filters and dispatches incoming messages from MetaBox.
     * @param messageType - Expected message type for filtering ('metaboxData').
     * @param event - The postMessage event received on window.
     */
    private handleMessageReceived;
    /**
     * Listens for MetaBox to signal readiness, then initializes communicator.
     * @param apiReadyCallback - Called with the new Communicator once MetaBox is loaded.
     */
    static createInstance(apiReadyCallback: (api: Communicator) => void): void;
    /**
     * Registers an event listener for messages dispatched by MetaBox.
     * @override
     */
    addEventListener<T extends FromMetaBoxApiEvents>(messageType: T, callback: (data: FromMetaboxMessagePayloads[T]) => void): this;
    /**
     * Dispatches a typed event to all registered listeners.
     * @override
     */
    dispatchEvent<T extends FromMetaBoxApiEvents>(messageType: T, data: FromMetaboxMessagePayloads[T]): this;
    /**
     * Removes a previously registered event listener.
     * @override
     */
    removeEventListener<T extends FromMetaBoxApiEvents>(messageType: T, callback: (data: FromMetaboxMessagePayloads[T]) => void): this;
}
