import { Communicator } from './Communicator';
/**
 * Integrates the MetaBox into the provided layout.
 *
 * @remarks
 * This function injects an iframe into a specified container element in the DOM and initializes
 * the communicator for interacting with the MetaBox embedded content.
 *
 * @param iframeSrc - The source URL of the MetaBox iframe.
 * Additional url parameters:
 * ```javascript
 * sidebar=false - disables the internal MetaBox menu
 * introImage=https://example.com/image.png - sets the intro image
 * ```
 * i.e. final link will look like https://metabox.3dsource.com/metabox-configurator/basic/your-configurator-id?sidebar=false&introImage=https://example.com/image.png
 *
 * @param containerId - The ID of the layout element. Defaults to 'embed3DSource'.
 * @param apiReadyCallback
 * @throws Error if the container element with the specified ID is not found.
 *
 * @example
 * import {
 *  integrateMetaBox,
 * } from '@3dsource/metabox-front-api';
 *
 * integrateMetaBox(
 *   'https://metabox.3dsource.com/metabox-configurator/basic/12345678-1234-1234-1234-01234567890?introImage=https://example.com/intro.webp&sidebar=false',
 *   'embed3DSource'
 * );
 */
export declare function integrateMetaBox(iframeSrc: string, containerId: string | undefined, apiReadyCallback: (api: Communicator) => void): void;
